//******************************************************************************
// FILE:       	icc430.h
//              
// AUTHOR:     	CC Cox
//              
// PROJECT:    	SynchroChron
//              
// DESCRIPTION:	ImageCraft ICC430 compatibility definitions
//				The assert() macro can be disabled by compiling with NDEBUG defined.
//
// HISTORY:
//		$Log: icc430.h,v $
//		Revision 1.3  2006-01-26 16:32:54-05  chuck
//		Release candidate
//
//		Revision 1.1 2006-01-13 chuck
//		Code review changes
//
//		Revision 1.0 2005-09-09 chuck
//		Initial revision
//
// Copyright (c) 2006 SynchroSystems Inc
// Use subject to terms of License Agreement at http://synchro.com/policies.html
//******************************************************************************

#ifndef __ICC430_H
#define __ICC430_H

//------------------------------------------------------------------------------
// include files
//------------------------------------------------------------------------------
#if F435 || F436 || F437
#include <msp430x43x.h>				// MSP430F43x definitions
#elif F447 || F448 || F449
#include <msp430x44x.h>				// MSP430F443x definitions
#endif
#include <assert.h>					// assert() support
#include <string.h>					// string functions (needed for assert())
#include <stdio.h>					// standard I/O support (needed for assert())

//******************************************************************************
// PUBLIC DECLARATIONS
//******************************************************************************

//------------------------------------------------------------------------------
// macros
//------------------------------------------------------------------------------
#define ITOA(str, num, radix)	itoa((str), (num), (radix))
#define interrupt(vector)		void
#define _assert(c, file, line)	LcdShowError("AS", strrchr((file), '\\') + 1, (line))

//------------------------------------------------------------------------------
// data types
//------------------------------------------------------------------------------
typedef char		PUTCHAR_ARG_TYPE;		// putchar(c) argument type

//------------------------------------------------------------------------------
// data
//------------------------------------------------------------------------------
// these symbols are generated by the linker to mark memory areas
extern char _lit_start;								// start of ROM
extern char _lit_end;
extern char _idata_start;
extern char _idata_end;
extern char _func_lit_start;
extern char _func_lit_end;
extern char _text_start;								
extern char _text_end;								// end of ROM 
extern char _data_start;							// start of RAM
extern char _data_end;
extern char _bss_start;								
extern char _bss_end;								// end of RAM 

#endif	// __ICC430_H
