//******************************************************************************
// FILE:       	lcd_font.h
//              
// AUTHOR:     	CC Cox - SynchroSystems
//              
// PROJECT:    	SynchroChron
//              
// DESCRIPTION:	LCD font definition header file
//
// HISTORY:
//		$Log: lcd_font.h,v $
//		Revision 1.5  2006-10-02 15:46:53-04  chuck
//		<>
//
//		Revision 1.4  2006-01-26 14:41:22-05  chuck
//		<>
//
//		Revision 1.3 2006-01-13 chuck
//		Code review changes
//
//		Revision 1.2 2006-01-12 chuck
//		Code review release
//
//		Revision 1.0 2005-03-14 chuck
//		Initial revision
//
// Copyright (c) 2006 SynchroSystems Inc
//******************************************************************************
#ifndef __LCD_FONT_H
#define __LCD_FONT_H

//******************************************************************************
// PRIVATE DECLARATIONS
//******************************************************************************

//------------------------------------------------------------------------------
// constants
//------------------------------------------------------------------------------
#define	DEL		0x7Fu				// DEL char, last in font

//------------------------------------------------------------------------------
// ROM data
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
//  OBJECT:			FONT_ASCII
//
//  DESCRIPTION:	Font table
//					Convert an ASCII character into a segment bit mask
//					Each line corresponds to a single character, number or punctuation
//					Each line consists of a 16 bit mask
//					Alphanumeric segment map:
//						 AAAAAAA
//						FH  J  KB
//						F H J K B
//						F  HJK  B
//						GGGG MMMM
//						E  QPN  C
//						E Q P N C
//						EQ  P  NC
//						 DDDDDDD
//------------------------------------------------------------------------------
static const UINT16 FONT_ASCII[] =
{
	// ASCII: 0x20
  	0,														// ' ' (space)
  	SEGF | SEGE,   											// ! (ugly)
  	SEGF | SEGB,											// "
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF | SEGG | 
		SEGH | SEGJ | SEGK | SEGM | SEGN | SEGP | SEGQ,		// # (== DEL)
	SEGA | SEGF | SEGG | SEGM | SEGC | SEGD | SEGJ | SEGP,	// $
	SEGF | SEGK | SEGQ | SEGC,								// %
	SEGA | SEGK | SEGG | SEGE | SEGD | SEGN | SEGH,			// &
	SEGJ,													// '
	SEGK | SEGN,											// ( (== '<')
	SEGH | SEGQ,											// ) (== '>')
	SEGH | SEGJ | SEGK | SEGG | SEGM | SEGQ | SEGP | SEGN,	// *
	SEGJ | SEGG | SEGM | SEGP,								// +
	SEGP,         											// ,
	SEGG | SEGM,											// -
	SEGD,         											// . (== '_')
	SEGK | SEGQ,											// /
	// ASCII: 0x30
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF,				// 0
	SEGC | SEGB,											// 1
	SEGA | SEGB | SEGM | SEGG | SEGE | SEGD,				// 2
	SEGA | SEGB | SEGM | SEGG | SEGC | SEGD,				// 3
	SEGF | SEGG | SEGM | SEGB | SEGC,						// 4
	SEGA | SEGF | SEGG | SEGM | SEGC | SEGD,				// 5
	SEGA | SEGF | SEGE | SEGD | SEGC | SEGM | SEGG,			// 6
	SEGA | SEGB | SEGC,										// 7
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF | SEGG | SEGM,	// 8
	SEGA | SEGF | SEGG | SEGM | SEGB | SEGC | SEGD,			// 9 (== 'g')
	SEGJ | SEGP,   											// : (ugly)
	SEGJ | SEGQ,   											// ; (ugly)
	SEGK | SEGN,											// < (== '(')
	SEGG | SEGM | SEGD,										// =
	SEGH | SEGQ,											// > (== ')')
	SEGA | SEGB | SEGM | SEGP,								// ?
	// ASCII: 0x40
	SEGA | SEGB | SEGD | SEGE | SEGF | SEGJ | SEGM,			// @
	SEGE | SEGF | SEGA | SEGB | SEGC | SEGG | SEGM,			// A
	SEGA | SEGB | SEGC | SEGD | SEGJ | SEGP | SEGM,			// B
	SEGA | SEGF | SEGE | SEGD,								// C
	SEGA | SEGB | SEGC | SEGD | SEGJ | SEGP,				// D
	SEGA | SEGF | SEGE | SEGD | SEGG | SEGM,				// E
	SEGA | SEGF | SEGE | SEGG | SEGM,						// F
	SEGA | SEGF | SEGE | SEGD | SEGC | SEGM,				// G
	SEGF | SEGE | SEGG | SEGM | SEGB | SEGC,				// H
	SEGA | SEGJ | SEGP | SEGD,								// I
	SEGB | SEGC | SEGD | SEGE,								// J
	SEGF | SEGE | SEGG | SEGK | SEGN,						// K
	SEGF | SEGE | SEGD,										// L
	SEGE | SEGF | SEGH | SEGK | SEGB | SEGC,				// M
	SEGE | SEGF | SEGH | SEGN | SEGC | SEGB,				// N
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF,				// O
	// ASCII: 0x50
	SEGE | SEGF | SEGA | SEGB | SEGG | SEGM,				// P
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF | SEGN,			// Q
	SEGE | SEGF | SEGA | SEGB | SEGG | SEGM | SEGN,			// R
	SEGA | SEGF | SEGG | SEGM | SEGC | SEGD,				// S
	SEGA | SEGJ | SEGP,										// T
	SEGF | SEGE | SEGD | SEGC | SEGB,						// U
	SEGF | SEGE | SEGQ | SEGK,								// V
	SEGF | SEGE | SEGQ | SEGN | SEGC | SEGB,				// W
	SEGH | SEGK | SEGQ | SEGN,								// X
	SEGF | SEGG | SEGM | SEGB | SEGP,						// Y
	SEGA | SEGK | SEGQ | SEGD,								// Z
	SEGA | SEGF | SEGE | SEGD,								// [
	SEGH | SEGN,											// backslash
	SEGA | SEGB | SEGC | SEGD,								// ]
	SEGF | SEGH,											// ^
	SEGD,													// _ (== '.')
	// ASCII: 0x60
	SEGH,													// `
	SEGG | SEGM | SEGE | SEGD | SEGN,						// a
	SEGF | SEGE | SEGD | SEGC | SEGG | SEGM,				// b
	SEGG | SEGM | SEGE | SEGD,								// c
	SEGG | SEGM | SEGE | SEGD | SEGC | SEGB,				// d
	SEGQ | SEGG | SEGE | SEGD,								// e
	SEGK | SEGG | SEGM | SEGP,								// f
	SEGA | SEGF | SEGG | SEGM | SEGB | SEGC | SEGD,			// g (== '9')
	SEGF | SEGE | SEGG | SEGM | SEGC,						// h
	SEGC,													// i
	SEGB | SEGC | SEGN,										// j
	SEGJ | SEGP | SEGM | SEGN,								// k
	SEGB | SEGC,											// l
	SEGE | SEGG | SEGM | SEGC | SEGP,						// m
	SEGE | SEGG | SEGM | SEGC,								// n
	SEGE | SEGG | SEGM | SEGC | SEGD,						// o
	// ASCII: 0x70
	SEGF | SEGE | SEGH | SEGG,								// p
	SEGB | SEGC | SEGM | SEGK,								// q
	SEGE | SEGG | SEGM,										// r
	SEGM | SEGN | SEGD,										// s
	SEGJ | SEGP | SEGG | SEGM,								// t
	SEGE | SEGD | SEGC,										// u
	SEGE | SEGQ,											// v
	SEGE | SEGQ | SEGN | SEGC,								// w
	SEGH | SEGK | SEGN | SEGQ,								// x
	SEGH | SEGK | SEGP,										// y
	SEGG | SEGQ | SEGD,										// z
	SEGK | SEGG | SEGN,										// {
	SEGJ | SEGP,											// |
	SEGH | SEGM | SEGQ,										// }
	SEGF | SEGH | SEGJ,										// ~
	SEGA | SEGB | SEGC | SEGD | SEGE | SEGF | SEGG | 
		SEGH | SEGJ | SEGK | SEGM | SEGN | SEGP | SEGQ,		// DEL (== '#')
};

#endif	// __LCD_FONT_H
